[Cmake-commits] CMake branch, master, updated. v3.12.3-862-g3ea9d81

Kitware Robot kwrobot at kitware.com
Tue Oct 9 06:35:03 EDT 2018


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
       via  3ea9d81da6499b5828c68d0c694ce0579efc555f (commit)
       via  fab2c2339b2b6a4310103f1fec74f6b8c55a8f01 (commit)
       via  424851742e0fb550cdf19c6db0882fd9b15f779e (commit)
       via  e9114f5bcfa41c51e23277e1129f469a6344dd35 (commit)
       via  db8920a2c53d53133dd44f74c2d6cd77fac308a1 (commit)
       via  bb60ed6e724b2891a33f3cd5b6e5aa300dcc4180 (commit)
       via  d0fb3e6c522e656b121911d791defb46ddecbc3b (commit)
       via  cd8c79e1633f091fca890df534d98e5eeb63b747 (commit)
      from  9df49ba020ebfa15571ce818631bed6043368c8e (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=3ea9d81da6499b5828c68d0c694ce0579efc555f
commit 3ea9d81da6499b5828c68d0c694ce0579efc555f
Merge: 4248517 fab2c23
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Tue Oct 9 10:34:01 2018 +0000
Commit:     Kitware Robot <kwrobot at kitware.com>
CommitDate: Tue Oct 9 06:34:06 2018 -0400

    Merge topic 'doc-regex-backslash'
    
    fab2c2339b Help: Fix documentation of escape sequences in a regex
    
    Acked-by: Kitware Robot <kwrobot at kitware.com>
    Merge-request: !2460


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=fab2c2339b2b6a4310103f1fec74f6b8c55a8f01
commit fab2c2339b2b6a4310103f1fec74f6b8c55a8f01
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Mon Oct 8 11:46:22 2018 -0400
Commit:     Brad King <brad.king at kitware.com>
CommitDate: Tue Oct 9 06:31:37 2018 -0400

    Help: Fix documentation of escape sequences in a regex
    
    Documentation added by commit 4b35dab891 (Help: Document how escape
    sequences work in a regex, 2018-07-18) is only correct for backslashes
    inside `[]` groups.  The regex engine does interpret `\` escapes
    elsewhere.  Fix the docs.
    
    Inspired-by: R2RT <artur.ryt at gmail.com>
    Fixes: #18428

diff --git a/Help/command/string.rst b/Help/command/string.rst
index 29a153a..cc18069 100644
--- a/Help/command/string.rst
+++ b/Help/command/string.rst
@@ -121,6 +121,11 @@ The following characters have special meaning in regular expressions:
   Matches at end of input
 ``.``
   Matches any single character
+``\<char>``
+  Matches the single character specified by ``<char>``.  Use this to
+  match special regex characters, e.g. ``\.`` for a literal ``.``
+  or ``\\`` for a literal backslash ``\``.  Escaping a non-special
+  character is unnecessary but allowed, e.g. ``\a`` matches ``a``.
 ``[ ]``
   Matches any character(s) inside the brackets
 ``[^ ]``
@@ -151,12 +156,9 @@ has lower precedence than concatenation.  This means that the regular
 expression ``^ab+d$`` matches ``abbd`` but not ``ababd``, and the regular
 expression ``^(ab|cd)$`` matches ``ab`` but not ``abd``.
 
-Backslash (``\``) characters in regular expressions are interpreted
-literally and do not escape anything or represent placeholders.
-However, CMake language :ref:`Escape Sequences` such as ``\t``,
-``\r``, ``\n``, and ``\\`` may be used to construct literal tabs,
-carriage returns, newlines, and backslashes (respectively) to pass
-in a regex.  For example:
+CMake language :ref:`Escape Sequences` such as ``\t``, ``\r``, ``\n``,
+and ``\\`` may be used to construct literal tabs, carriage returns,
+newlines, and backslashes (respectively) to pass in a regex.  For example:
 
 * The quoted argument ``"[ \t\r\n]"`` specifies a regex that matches
   any single whitespace character.
@@ -164,6 +166,11 @@ in a regex.  For example:
   a single forward slash ``/`` or backslash ``\``.
 * The quoted argument ``"[A-Za-z0-9_]"`` specifies a regex that matches
   any single "word" character in the C locale.
+* The quoted argument ``"\\(\\a\\+b\\)"`` specifies a regex that matches
+  the exact string ``(a+b)``.  Each ``\\`` is parsed in a quoted argument
+  as just ``\``, so the regex itself is actually ``\(\a\+\b\)``.  This
+  can alternatively be specified in a :ref:`bracket argument` without
+  having to escape the backslashes, e.g. ``[[\(\a\+\b\)]]``.
 
 Manipulation
 ^^^^^^^^^^^^

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=424851742e0fb550cdf19c6db0882fd9b15f779e
commit 424851742e0fb550cdf19c6db0882fd9b15f779e
Merge: e9114f5 d0fb3e6
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Tue Oct 9 10:27:34 2018 +0000
Commit:     Kitware Robot <kwrobot at kitware.com>
CommitDate: Tue Oct 9 06:27:55 2018 -0400

    Merge topic 'mkl_ilp64'
    
    d0fb3e6c52 Find{BLAS,LAPACK}: Find also ILP64 MKL BLAS and LAPACK
    
    Acked-by: Kitware Robot <kwrobot at kitware.com>
    Merge-request: !2444


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e9114f5bcfa41c51e23277e1129f469a6344dd35
commit e9114f5bcfa41c51e23277e1129f469a6344dd35
Merge: db8920a bb60ed6
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Tue Oct 9 10:27:16 2018 +0000
Commit:     Kitware Robot <kwrobot at kitware.com>
CommitDate: Tue Oct 9 06:27:21 2018 -0400

    Merge topic 'vs-flag-map-Qspectre'
    
    bb60ed6e72 VS: Add flag table entry for -Qspectre
    
    Acked-by: Kitware Robot <kwrobot at kitware.com>
    Merge-request: !2462


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=db8920a2c53d53133dd44f74c2d6cd77fac308a1
commit db8920a2c53d53133dd44f74c2d6cd77fac308a1
Merge: 9df49ba cd8c79e
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Tue Oct 9 10:24:42 2018 +0000
Commit:     Kitware Robot <kwrobot at kitware.com>
CommitDate: Tue Oct 9 06:25:13 2018 -0400

    Merge topic 'doc-target_link_libraries-keywords-not-genex'
    
    cd8c79e163 Help: Clarify target_link_libraries keywords and generator expressions
    
    Acked-by: Kitware Robot <kwrobot at kitware.com>
    Merge-request: !2449


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=bb60ed6e724b2891a33f3cd5b6e5aa300dcc4180
commit bb60ed6e724b2891a33f3cd5b6e5aa300dcc4180
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Mon Oct 8 13:51:29 2018 -0400
Commit:     Brad King <brad.king at kitware.com>
CommitDate: Mon Oct 8 14:03:39 2018 -0400

    VS: Add flag table entry for -Qspectre
    
    Add special logic to map this flag to a top-level build setting
    instead of being in ClCompile.
    
    Fixes: #18426

diff --git a/Source/cmVS141CLFlagTable.h b/Source/cmVS141CLFlagTable.h
index 7d3e356..2a9944a 100644
--- a/Source/cmVS141CLFlagTable.h
+++ b/Source/cmVS141CLFlagTable.h
@@ -83,6 +83,8 @@ static cmVS7FlagTable cmVS141CLFlagTable[] = {
   { "FloatingPointModel", "fp:strict", "Strict", "Strict", 0 },
   { "FloatingPointModel", "fp:fast", "Fast", "Fast", 0 },
 
+  { "SpectreMitigation", "Qspectre", "Spectre mitigations", "Spectre", 0 },
+
   { "LanguageStandard", "std:c++17", "ISO C++17 Standard", "stdcpp17", 0 },
   { "LanguageStandard", "std:c++14", "ISO C++14 Standard", "stdcpp14", 0 },
   { "LanguageStandard", "std:c++latest", "ISO C++ Latest Draft Standard",
diff --git a/Source/cmVisualStudio10TargetGenerator.cxx b/Source/cmVisualStudio10TargetGenerator.cxx
index 16eca96..57d66e0 100644
--- a/Source/cmVisualStudio10TargetGenerator.cxx
+++ b/Source/cmVisualStudio10TargetGenerator.cxx
@@ -1125,6 +1125,9 @@ void cmVisualStudio10TargetGenerator::WriteMSToolConfigurationValues(
   if (this->IPOEnabledConfigurations.count(config) > 0) {
     e1.Element("WholeProgramOptimization", "true");
   }
+  if (this->SpectreMitigationConfigurations.count(config) > 0) {
+    e1.Element("SpectreMitigation", "Spectre");
+  }
 }
 
 void cmVisualStudio10TargetGenerator::WriteMSToolConfigurationValuesManaged(
@@ -2625,6 +2628,11 @@ bool cmVisualStudio10TargetGenerator::ComputeClOptions(
     }
   }
 
+  if (clOptions.HasFlag("SpectreMitigation")) {
+    this->SpectreMitigationConfigurations.insert(configName);
+    clOptions.RemoveFlag("SpectreMitigation");
+  }
+
   this->ClOptions[configName] = std::move(pOptions);
   return true;
 }
diff --git a/Source/cmVisualStudio10TargetGenerator.h b/Source/cmVisualStudio10TargetGenerator.h
index 829d2bf..0dc03b6 100644
--- a/Source/cmVisualStudio10TargetGenerator.h
+++ b/Source/cmVisualStudio10TargetGenerator.h
@@ -205,6 +205,7 @@ private:
   unsigned int NsightTegraVersion[4];
   bool TargetCompileAsWinRT;
   std::set<std::string> IPOEnabledConfigurations;
+  std::set<std::string> SpectreMitigationConfigurations;
   cmGlobalVisualStudio10Generator* const GlobalGenerator;
   cmLocalVisualStudio10Generator* const LocalGenerator;
   std::set<std::string> CSharpCustomCommandNames;

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=d0fb3e6c522e656b121911d791defb46ddecbc3b
commit d0fb3e6c522e656b121911d791defb46ddecbc3b
Author:     Jakub Benda <jakub.benda at seznam.cz>
AuthorDate: Wed Oct 3 22:40:17 2018 +0100
Commit:     Brad King <brad.king at kitware.com>
CommitDate: Mon Oct 8 13:21:08 2018 -0400

    Find{BLAS,LAPACK}: Find also ILP64 MKL BLAS and LAPACK
    
    Modern Intel MKL packages offer 64-bit BLAS and LAPACK libraries in any
    of the eight combinations of the following three binary options:
    
      - sequential or threaded
      - LP64 or ILP64
      - static or shared
    
    The modules FindBLAS and FindLAPACK did not allow full selection of
    arbitrary combination; in particular, only LP64 variant was used.
    
    The original list of possible BLA_VENDOR values related to MKL,
    
      Intel10_64lp
      Intel10_64lp_seq
    
    is thus extended by another pair of "vendors",
    
      Intel10_64ilp
      Intel10_64ilp_seq
    
    Depending on the selection, either "_lp64", or "_ilp64" MKL libraries
    are searched for. Some comments in the two CMake modules were modified
    to indicate that even though the "vendors" contain the number "10",
    they also apply to all further versions of MKL.

diff --git a/Modules/FindLAPACK.cmake b/Modules/FindLAPACK.cmake
index a3c87f8..7ca9950 100644
--- a/Modules/FindLAPACK.cmake
+++ b/Modules/FindLAPACK.cmake
@@ -278,6 +278,12 @@ if (BLA_VENDOR MATCHES "Intel" OR BLA_VENDOR STREQUAL "All")
       find_package(Threads REQUIRED)
     endif()
 
+    if (BLA_VENDOR MATCHES "_64ilp")
+      set(BLAS_mkl_ILP_MODE "ilp64")
+    else ()
+      set(BLAS_mkl_ILP_MODE "lp64")
+    endif ()
+
     set(LAPACK_SEARCH_LIBS "")
 
     if (BLA_F95)
@@ -292,7 +298,7 @@ if (BLA_VENDOR MATCHES "Intel" OR BLA_VENDOR STREQUAL "All")
       list(APPEND LAPACK_SEARCH_LIBS
         "mkl_intel_c")
       list(APPEND LAPACK_SEARCH_LIBS
-        "mkl_intel_lp64")
+        "mkl_intel_${BLAS_mkl_ILP_MODE}")
     else()
       set(LAPACK_mkl_SEARCH_SYMBOL "cheev")
       set(_LIBRARIES LAPACK_LIBRARIES)
@@ -303,7 +309,7 @@ if (BLA_VENDOR MATCHES "Intel" OR BLA_VENDOR STREQUAL "All")
         "mkl_lapack")
       # new >= 10.3
       list(APPEND LAPACK_SEARCH_LIBS
-        "mkl_gf_lp64")
+        "mkl_gf_${BLAS_mkl_ILP_MODE}")
     endif()
 
     # First try empty lapack libs
@@ -332,6 +338,8 @@ if (BLA_VENDOR MATCHES "Intel" OR BLA_VENDOR STREQUAL "All")
           )
       endif ()
     endforeach ()
+
+    unset(BLAS_mkl_ILP_MODE)
   endif ()
 endif()
 else()

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=cd8c79e1633f091fca890df534d98e5eeb63b747
commit cd8c79e1633f091fca890df534d98e5eeb63b747
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Fri Oct 5 09:54:29 2018 -0400
Commit:     Brad King <brad.king at kitware.com>
CommitDate: Mon Oct 8 11:18:14 2018 -0400

    Help: Clarify target_link_libraries keywords and generator expressions
    
    The `optimized` and `debug` keyword items are meaningful only to
    the `target_link_libraries` command and have no meaning when
    produced by a generator expression.  State this explicitly.
    Also recommend use of a quoted argument when the genex itself
    may contain a semicolon.
    
    Fixes: #18424

diff --git a/Help/command/target_link_libraries.rst b/Help/command/target_link_libraries.rst
index e1c374e..229d10c 100644
--- a/Help/command/target_link_libraries.rst
+++ b/Help/command/target_link_libraries.rst
@@ -78,6 +78,20 @@ Each ``<item>`` may be:
   flags explicitly. The flags will then be placed at the toolchain-defined
   flag position in the link command.
 
+* **A generator expression**: A ``$<...>`` :manual:`generator expression
+  <cmake-generator-expressions(7)>` may evaluate to any of the above
+  items or to a :ref:`;-list <CMake Language Lists>` of them.
+  If the ``...`` contains any ``;`` characters, e.g. after evaluation
+  of a ``${list}`` variable, be sure to use an explicitly quoted
+  argument ``"$<...>"`` so that this command receives it as a
+  single ``<item>``.
+
+  Additionally, a generator expression may be used as a fragment of
+  any of the above items, e.g. ``foo$<1:_d>``.
+
+  Note that generator expressions will not be used in OLD handling of
+  policy :policy:`CMP0003` or policy :policy:`CMP0004`.
+
 * A ``debug``, ``optimized``, or ``general`` keyword immediately followed
   by another ``<item>``.  The item following such a keyword will be used
   only for the corresponding build configuration.  The ``debug`` keyword
@@ -88,18 +102,16 @@ Each ``<item>`` may be:
   optional.  Higher granularity may be achieved for per-configuration
   rules by creating and linking to
   :ref:`IMPORTED library targets <Imported Targets>`.
+  These keywords are interpreted immediately by this command and therefore
+  have no special meaning when produced by a generator expression.
 
 Items containing ``::``, such as ``Foo::Bar``, are assumed to be
 :ref:`IMPORTED <Imported Targets>` or :ref:`ALIAS <Alias Targets>` library
 target names and will cause an error if no such target exists.
 See policy :policy:`CMP0028`.
 
-Arguments to ``target_link_libraries`` may use "generator expressions"
-with the syntax ``$<...>``.  Note however, that generator expressions
-will not be used in OLD handling of :policy:`CMP0003` or :policy:`CMP0004`.
-See the :manual:`cmake-generator-expressions(7)` manual for available
-expressions.  See the :manual:`cmake-buildsystem(7)` manual for more on
-defining buildsystem properties.
+See the :manual:`cmake-buildsystem(7)` manual for more on defining
+buildsystem properties.
 
 Libraries for a Target and/or its Dependents
 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

-----------------------------------------------------------------------

Summary of changes:
 Help/command/string.rst                    | 19 ++++++++----
 Help/command/target_link_libraries.rst     | 24 ++++++++++++----
 Modules/FindBLAS.cmake                     | 46 ++++++++++++++++++------------
 Modules/FindLAPACK.cmake                   | 12 ++++++--
 Source/cmVS141CLFlagTable.h                |  2 ++
 Source/cmVisualStudio10TargetGenerator.cxx |  8 ++++++
 Source/cmVisualStudio10TargetGenerator.h   |  1 +
 7 files changed, 79 insertions(+), 33 deletions(-)


hooks/post-receive
diff --git a/Modules/FindBLAS.cmake b/Modules/FindBLAS.cmake
index 39b9b74..e955bc2 100644
--- a/Modules/FindBLAS.cmake
+++ b/Modules/FindBLAS.cmake
@@ -53,8 +53,10 @@
 # * SGIMATH
 # * IBMESSL
 # * Intel10_32 (intel mkl v10 32 bit)
 # * Intel10_64lp (intel mkl v10 64 bit, lp thread model, lp64 model)
 # * Intel10_64lp_seq (intel mkl v10 64 bit, sequential code, lp64 model)
 # * Intel (older versions of mkl 32 and 64 bit)
 # * ACML
 # * ACML_MP
@@ -199,9 +201,14 @@ if (BLA_VENDOR STREQUAL "All")
   endif()
 endif ()
 
-#BLAS in intel mkl 10 library? (em64t 64bit)
+#BLAS in intel mkl 10+ library? (em64t 64bit)
 if (BLA_VENDOR MATCHES "Intel" OR BLA_VENDOR STREQUAL "All")
   if (NOT BLAS_LIBRARIES)
+    if (BLA_VENDOR MATCHES "_64ilp")
+      set(BLAS_mkl_ILP_MODE "ilp64")
+    else ()
+      set(BLAS_mkl_ILP_MODE "lp64")
+    endif ()
     if (NOT WIN32)
       set(LM "-lm")
     endif ()
@@ -230,9 +237,9 @@ if (BLA_VENDOR MATCHES "Intel" OR BLA_VENDOR STREQUAL "All")
             list(APPEND BLAS_SEARCH_LIBS_WIN_MAIN
               "mkl_blas95${BLAS_mkl_DLL_SUFFIX} mkl_intel_c${BLAS_mkl_DLL_SUFFIX}")
           endif()
-          if (BLA_VENDOR MATCHES "^Intel10_64lp" OR BLA_VENDOR STREQUAL "All")
+          if (BLA_VENDOR MATCHES "^Intel10_64i?lp" OR BLA_VENDOR STREQUAL "All")
             list(APPEND BLAS_SEARCH_LIBS_WIN_MAIN
-              "mkl_blas95_lp64${BLAS_mkl_DLL_SUFFIX} mkl_intel_lp64${BLAS_mkl_DLL_SUFFIX}")
+              "mkl_blas95_${BLAS_mkl_ILP_MODE}${BLAS_mkl_DLL_SUFFIX} mkl_intel_${BLAS_mkl_ILP_MODE}${BLAS_mkl_DLL_SUFFIX}")
           endif ()
 
           # Add threading/sequential libs
@@ -262,23 +269,23 @@ if (BLA_VENDOR MATCHES "Intel" OR BLA_VENDOR STREQUAL "All")
             list(APPEND BLAS_SEARCH_LIBS
               "mkl_blas95 mkl_intel mkl_intel_thread mkl_core guide")
           endif ()
-          if (BLA_VENDOR STREQUAL "Intel10_64lp" OR BLA_VENDOR STREQUAL "All")
+          if (BLA_VENDOR MATCHES "^Intel10_64i?lp$" OR BLA_VENDOR STREQUAL "All")
             # old version
             list(APPEND BLAS_SEARCH_LIBS
-              "mkl_blas95 mkl_intel_lp64 mkl_intel_thread mkl_core guide")
+              "mkl_blas95 mkl_intel_${BLAS_mkl_ILP_MODE} mkl_intel_thread mkl_core guide")
 
             # mkl >= 10.3
             if (CMAKE_C_COMPILER MATCHES ".+gcc")
               list(APPEND BLAS_SEARCH_LIBS
-                "mkl_blas95_lp64 mkl_intel_lp64 mkl_gnu_thread mkl_core gomp")
+                "mkl_blas95_${BLAS_mkl_ILP_MODE} mkl_intel_${BLAS_mkl_ILP_MODE} mkl_gnu_thread mkl_core gomp")
             else ()
               list(APPEND BLAS_SEARCH_LIBS
-                "mkl_blas95_lp64 mkl_intel_lp64 mkl_intel_thread mkl_core iomp5")
+                "mkl_blas95_${BLAS_mkl_ILP_MODE} mkl_intel_${BLAS_mkl_ILP_MODE} mkl_intel_thread mkl_core iomp5")
             endif ()
           endif ()
-          if (BLA_VENDOR STREQUAL "Intel10_64lp_seq" OR BLA_VENDOR STREQUAL "All")
+          if (BLA_VENDOR MATCHES "^Intel10_64i?lp_seq$" OR BLA_VENDOR STREQUAL "All")
             list(APPEND BLAS_SEARCH_LIBS
-              "mkl_intel_lp64 mkl_sequential mkl_core")
+              "mkl_blas95_${BLAS_mkl_ILP_MODE} mkl_intel_${BLAS_mkl_ILP_MODE} mkl_sequential mkl_core")
           endif ()
         endif ()
       else ()
@@ -297,9 +304,9 @@ if (BLA_VENDOR MATCHES "Intel" OR BLA_VENDOR STREQUAL "All")
             list(APPEND BLAS_SEARCH_LIBS_WIN_MAIN
               "mkl_intel_c${BLAS_mkl_DLL_SUFFIX}")
           endif()
-          if (BLA_VENDOR MATCHES "^Intel10_64lp" OR BLA_VENDOR STREQUAL "All")
+          if (BLA_VENDOR MATCHES "^Intel10_64i?lp" OR BLA_VENDOR STREQUAL "All")
             list(APPEND BLAS_SEARCH_LIBS_WIN_MAIN
-              "mkl_intel_lp64${BLAS_mkl_DLL_SUFFIX}")
+              "mkl_intel_${BLAS_mkl_ILP_MODE}${BLAS_mkl_DLL_SUFFIX}")
           endif ()
 
           # Add threading/sequential libs
@@ -329,24 +336,24 @@ if (BLA_VENDOR MATCHES "Intel" OR BLA_VENDOR STREQUAL "All")
             list(APPEND BLAS_SEARCH_LIBS
               "mkl_intel mkl_intel_thread mkl_core guide")
           endif ()
-          if (BLA_VENDOR STREQUAL "Intel10_64lp" OR BLA_VENDOR STREQUAL "All")
+          if (BLA_VENDOR MATCHES "^Intel10_64i?lp$" OR BLA_VENDOR STREQUAL "All")
 
             # old version
             list(APPEND BLAS_SEARCH_LIBS
-              "mkl_intel_lp64 mkl_intel_thread mkl_core guide")
+              "mkl_intel_${BLAS_mkl_ILP_MODE} mkl_intel_thread mkl_core guide")
 
             # mkl >= 10.3
             if (CMAKE_C_COMPILER MATCHES ".+gcc")
               list(APPEND BLAS_SEARCH_LIBS
-                "mkl_intel_lp64 mkl_gnu_thread mkl_core gomp")
+                "mkl_intel_${BLAS_mkl_ILP_MODE} mkl_gnu_thread mkl_core gomp")
             else ()
               list(APPEND BLAS_SEARCH_LIBS
-                "mkl_intel_lp64 mkl_intel_thread mkl_core iomp5")
+                "mkl_intel_${BLAS_mkl_ILP_MODE} mkl_intel_thread mkl_core iomp5")
             endif ()
           endif ()
-          if (BLA_VENDOR STREQUAL "Intel10_64lp_seq" OR BLA_VENDOR STREQUAL "All")
+          if (BLA_VENDOR MATCHES "^Intel10_64i?lp_seq$" OR BLA_VENDOR STREQUAL "All")
             list(APPEND BLAS_SEARCH_LIBS
-              "mkl_intel_lp64 mkl_sequential mkl_core")
+              "mkl_intel_${BLAS_mkl_ILP_MODE} mkl_sequential mkl_core")
           endif ()
 
           #older vesions of intel mkl libs
@@ -376,6 +383,7 @@ if (BLA_VENDOR MATCHES "Intel" OR BLA_VENDOR STREQUAL "All")
       endforeach ()
 
     endif ()
+    unset(BLAS_mkl_ILP_MODE)
   endif ()
 endif ()
 
@@ -53,8 +53,10 @@
 # * IBMESSL
 # * Intel10_32 (intel mkl v10 32 bit)
-# * Intel10_64lp (intel mkl v10 64 bit, lp thread model, lp64 model)
-# * Intel10_64lp_seq (intel mkl v10 64 bit, sequential code, lp64 model)
+# * Intel10_64lp (intel mkl v10+ 64 bit, threaded code, lp64 model)
+# * Intel10_64lp_seq (intel mkl v10+ 64 bit, sequential code, lp64 model)
+# * Intel10_64ilp (intel mkl v10+ 64 bit, threaded code, ilp64 model)
+# * Intel10_64ilp_seq (intel mkl v10+ 64 bit, sequential code, ilp64 model)
 # * Intel (older versions of mkl 32 and 64 bit)
 # * ACML
-- 
CMake


More information about the Cmake-commits mailing list